summaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
authorTero Ahola <tero.ahola@digia.com>2012-09-07 09:38:44 +0300
committerTero Ahola <tero.ahola@digia.com>2012-09-10 10:03:11 +0300
commit0715a02a08e55d9c14d6a2a19c39ebda410c02bd (patch)
treed6c12aae8a047da8af1d9cfd4d2f7514e0bd2402 /tools
parent6a45d36aa2215e93c624109ce71e6baab32fb22c (diff)
Added QML_IMPORT_PATH to run_tests script for OSX
Diffstat (limited to 'tools')
-rw-r--r--tools/run_tests.pl33
1 files changed, 19 insertions, 14 deletions
diff --git a/tools/run_tests.pl b/tools/run_tests.pl
index a512e33c..f71fb304 100644
--- a/tools/run_tests.pl
+++ b/tools/run_tests.pl
@@ -24,21 +24,26 @@ mkdir $reports_path;
# setup environment for running tests
given ($job{'Platform'}) {
- when ("Win7") {
- # Add qtdir to path
- $ENV{'PATH'} .= ";" . $job{'QtDir'} . "\\bin";
-
- # replace / -> \
- $ENV{'PATH'} =~ s/\//\\/g;
- }
+ when ("Win7") {
+ # Add qtdir to path
+ $ENV{'PATH'} .= ";" . $job{'QtDir'} . "\\bin";
- when ("Linux") {
- # Add qtdir to path
- $ENV{'PATH'} = $job{'QtDir'} . "/bin:" . $ENV{'PATH'};
-
- # If this is not set we get "cannot connect to X server" errors
- $ENV{'DISPLAY'} = ":0.0";
- }
+ # replace / -> \
+ $ENV{'PATH'} =~ s/\//\\/g;
+ }
+
+ when ("Linux") {
+ # Add qtdir to path
+ $ENV{'PATH'} = $job{'QtDir'} . "/bin:" . $ENV{'PATH'};
+
+ # If this is not set we get "cannot connect to X server" errors
+ $ENV{'DISPLAY'} = ":0.0";
+ }
+
+ when ("Mac") {
+ # Set QML_IMPORT_PATH point to QML plugin dir
+ $ENV{'QML_IMPORT_PATH'} = $bin_path;
+ }
}
# Go through all the files in the test folder